@@ -874,7 +874,7 @@ struct MHD_Connection
   /**
    * true if #socket_fd is non-blocking, false otherwise.
    */
-  bool sk_nonblck; // FIXME: hopefully dead?
+  bool sk_nonblck;
 
   /**
    * Indicate whether connection socket has TCP_CORK / Nagle’s algorithm turned on/off
@@ -1460,6 +1460,12 @@ struct MHD_Daemon
    */
   size_t thread_stack_size;
 
+  /**
+   * Our #MHD_OPTION_SERVER_INSANITY level, bits indicating
+   * which sanity checks are off.
+   */
+  enum MHD_DisableSanityCheck insanity_level;
+
   /**
    * Number of worker daemons
    */
