@@ -35,9 +35,10 @@
 #include "mhd_options.h"
 
 #include <errno.h>
+#include <stdbool.h>
 
-#if !defined(MHD_POSIX_SOCKETS) && !defined(MHD_WINSOCK_SOCKETS)
-#  if !defined(_WIN32) || defined(__CYGWIN__)
+#if ! defined(MHD_POSIX_SOCKETS) && ! defined(MHD_WINSOCK_SOCKETS)
+#  if ! defined(_WIN32) || defined(__CYGWIN__)
 #    define MHD_POSIX_SOCKETS 1
 #  else  /* defined(_WIN32) && !defined(__CYGWIN__) */
 #    define MHD_WINSOCK_SOCKETS 1
@@ -92,7 +93,7 @@
 #    include <sys/epoll.h>
 #  endif
 #  ifdef HAVE_NETINET_TCP_H
-     /* for TCP_FASTOPEN and TCP_CORK */
+/* for TCP_FASTOPEN and TCP_CORK */
 #    include <netinet/tcp.h>
 #  endif
 #  ifdef HAVE_STRING_H
@@ -111,10 +112,10 @@
 #endif
 
 #include <stddef.h>
-#if defined(_MSC_FULL_VER) && !defined (_SSIZE_T_DEFINED)
+#if defined(_MSC_FULL_VER) && ! defined (_SSIZE_T_DEFINED)
 #  include <stdint.h>
 #  define _SSIZE_T_DEFINED
-   typedef intptr_t ssize_t;
+typedef intptr_t ssize_t;
 #endif /* !_SSIZE_T_DEFINED */
 
 #include "mhd_limits.h"
@@ -123,7 +124,7 @@
 #  define _MHD_SYS_DEFAULT_FD_SETSIZE FD_SETSIZE
 #else  /* ! _MHD_FD_SETSIZE_IS_DEFAULT */
 #  include "sysfdsetsize.h"
-#  define _MHD_SYS_DEFAULT_FD_SETSIZE get_system_fdsetsize_value()
+#  define _MHD_SYS_DEFAULT_FD_SETSIZE get_system_fdsetsize_value ()
 #endif /* ! _MHD_FD_SETSIZE_IS_DEFAULT */
 
 #ifndef MHD_PANIC
@@ -131,8 +132,9 @@
 #  include <stdlib.h>
 /* Simple implementation of MHD_PANIC, to be used outside lib */
 #  define MHD_PANIC(msg) do { fprintf (stderr,           \
-     "Abnormal termination at %d line in file %s: %s\n", \
-     (int)__LINE__, __FILE__, msg); abort();} while(0)
+                                       "Abnormal termination at %d line in file %s: %s\n", \
+                                       (int) __LINE__, __FILE__, msg); abort (); \
+} while (0)
 #endif /* ! MHD_PANIC */
 
 #ifndef MHD_SOCKET_DEFINED
@@ -140,10 +142,10 @@
  * MHD_socket is type for socket FDs
  */
 #  if defined(MHD_POSIX_SOCKETS)
-     typedef int MHD_socket;
+typedef int MHD_socket;
 #    define MHD_INVALID_SOCKET (-1)
 #  elif defined(MHD_WINSOCK_SOCKETS)
-     typedef SOCKET MHD_socket;
+typedef SOCKET MHD_socket;
 #    define MHD_INVALID_SOCKET (INVALID_SOCKET)
 #  endif /* MHD_WINSOCK_SOCKETS */
 
@@ -174,17 +176,18 @@
 #  define MAYBE_MSG_NOSIGNAL 0
 #endif /* ! MSG_NOSIGNAL */
 
-#if !defined(SHUT_WR) && defined(SD_SEND)
+#if ! defined(SHUT_WR) && defined(SD_SEND)
 #  define SHUT_WR SD_SEND
 #endif
-#if !defined(SHUT_RD) && defined(SD_RECEIVE)
+#if ! defined(SHUT_RD) && defined(SD_RECEIVE)
 #  define SHUT_RD SD_RECEIVE
 #endif
-#if !defined(SHUT_RDWR) && defined(SD_BOTH)
+#if ! defined(SHUT_RDWR) && defined(SD_BOTH)
 #  define SHUT_RDWR SD_BOTH
 #endif
 
-#if HAVE_ACCEPT4+0 != 0 && (defined(HAVE_SOCK_NONBLOCK) || defined(SOCK_CLOEXEC) || defined(SOCK_NOSIGPIPE))
+#if HAVE_ACCEPT4 + 0 != 0 && (defined(HAVE_SOCK_NONBLOCK) || \
+  defined(SOCK_CLOEXEC) || defined(SOCK_NOSIGPIPE))
 #  define USE_ACCEPT4 1
 #endif
 
@@ -217,25 +220,25 @@
  * MHD_SCKT_OPT_BOOL_ is type for bool parameters for setsockopt()/getsockopt()
  */
 #ifdef MHD_POSIX_SOCKETS
-  typedef int MHD_SCKT_OPT_BOOL_;
+typedef int MHD_SCKT_OPT_BOOL_;
 #else /* MHD_WINSOCK_SOCKETS */
-  typedef BOOL MHD_SCKT_OPT_BOOL_;
+typedef BOOL MHD_SCKT_OPT_BOOL_;
 #endif /* MHD_WINSOCK_SOCKETS */
 
 /**
  * MHD_SCKT_SEND_SIZE_ is type used to specify size for send and recv
  * functions
  */
-#if !defined(MHD_WINSOCK_SOCKETS)
-  typedef size_t MHD_SCKT_SEND_SIZE_;
+#if ! defined(MHD_WINSOCK_SOCKETS)
+typedef size_t MHD_SCKT_SEND_SIZE_;
 #else
-  typedef int MHD_SCKT_SEND_SIZE_;
+typedef int MHD_SCKT_SEND_SIZE_;
 #endif
 
 /**
  * MHD_SCKT_SEND_MAX_SIZE_ is maximum send()/recv() size value.
  */
-#if !defined(MHD_WINSOCK_SOCKETS)
+#if ! defined(MHD_WINSOCK_SOCKETS)
 #  define MHD_SCKT_SEND_MAX_SIZE_ SSIZE_MAX
 #else
 #  define MHD_SCKT_SEND_MAX_SIZE_ INT_MAX
@@ -251,10 +254,10 @@
  *         counted as success, only EBADF counts as an error!),
  *         boolean false otherwise.
  */
-#if !defined(MHD_WINSOCK_SOCKETS)
-#  define MHD_socket_close_(fd) ((0 == close((fd))) || (EBADF != errno))
+#if ! defined(MHD_WINSOCK_SOCKETS)
+#  define MHD_socket_close_(fd) ((0 == close ((fd))) || (EBADF != errno))
 #else
-#  define MHD_socket_close_(fd) (0 == closesocket((fd)))
+#  define MHD_socket_close_(fd) (0 == closesocket ((fd)))
 #endif
 
 /**
@@ -263,9 +266,9 @@
  * @param fd socket to close
  */
 #define MHD_socket_close_chk_(fd) do {        \
-    if (!MHD_socket_close_(fd))               \
-      MHD_PANIC(_("Close socket failed.\n")); \
-  } while(0)
+    if (! MHD_socket_close_ (fd))               \
+      MHD_PANIC (_ ("Close socket failed.\n")); \
+} while (0)
 
 
 /**
@@ -276,7 +279,8 @@
  * @return ssize_t type value
  */
 #define MHD_send_(s,b,l) \
-  ((ssize_t)send((s),(const void*)(b),(MHD_SCKT_SEND_SIZE_)(l), MAYBE_MSG_NOSIGNAL))
+  ((ssize_t) send ((s),(const void*) (b),(MHD_SCKT_SEND_SIZE_) (l), \
+                   MAYBE_MSG_NOSIGNAL))
 
 
 /**
@@ -287,7 +291,7 @@
  * @return ssize_t type value
  */
 #define MHD_recv_(s,b,l) \
-  ((ssize_t)recv((s),(void*)(b),(MHD_SCKT_SEND_SIZE_)(l), 0))
+  ((ssize_t) recv ((s),(void*) (b),(MHD_SCKT_SEND_SIZE_) (l), 0))
 
 
 /**
@@ -300,11 +304,18 @@
  *         boolean false otherwise.
  */
 #if defined(MHD_POSIX_SOCKETS)
-#  define MHD_SCKT_FD_FITS_FDSET_SETSIZE_(fd,pset,setsize) ((fd) < ((MHD_socket)setsize))
+#  define MHD_SCKT_FD_FITS_FDSET_SETSIZE_(fd,pset,setsize) ((fd) < \
+                                                            ((MHD_socket) \
+                                                             setsize))
 #elif defined(MHD_WINSOCK_SOCKETS)
-#  define MHD_SCKT_FD_FITS_FDSET_SETSIZE_(fd,pset,setsize) ( ((void*)(pset)==(void*)0) || \
-                                                             (((fd_set*)(pset))->fd_count < ((unsigned)setsize)) || \
-                                                             (FD_ISSET((fd),(pset))) )
+#  define MHD_SCKT_FD_FITS_FDSET_SETSIZE_(fd,pset,setsize) ( ((void*) (pset)== \
+                                                              (void*) 0) || \
+                                                             (((fd_set*) (pset)) \
+                                                              ->fd_count < \
+                                                              ((unsigned) \
+                                                               setsize)) || \
+                                                             (FD_ISSET ((fd), \
+                                                                        (pset))) )
 #endif
 
 /**
@@ -315,7 +326,9 @@
  * @return boolean true if FD can be added to fd_set,
  *         boolean false otherwise.
  */
-#define MHD_SCKT_FD_FITS_FDSET_(fd,pset) MHD_SCKT_FD_FITS_FDSET_SETSIZE_((fd),(pset),FD_SETSIZE)
+#define MHD_SCKT_FD_FITS_FDSET_(fd,pset) MHD_SCKT_FD_FITS_FDSET_SETSIZE_ ((fd), \
+                                                                          (pset), \
+                                                                          FD_SETSIZE)
 
 /**
  * Add FD to fd_set with specified FD_SETSIZE.
@@ -326,34 +339,35 @@
  *        system definition of FD_SET() is not used.
  */
 #if defined(MHD_POSIX_SOCKETS)
-#  define MHD_SCKT_ADD_FD_TO_FDSET_SETSIZE_(fd,pset,setsize) FD_SET((fd),(pset))
+#  define MHD_SCKT_ADD_FD_TO_FDSET_SETSIZE_(fd,pset,setsize) FD_SET ((fd), \
+                                                                     (pset))
 #elif defined(MHD_WINSOCK_SOCKETS)
 #  define MHD_SCKT_ADD_FD_TO_FDSET_SETSIZE_(fd,pset,setsize)                     \
-        do {                                                                     \
-           u_int _i_ = 0;                                                        \
-           fd_set* const _s_ = (fd_set*)(pset);                                  \
-           while((_i_ < _s_->fd_count) && ((fd) != _s_->fd_array[_i_])) {++_i_;} \
-           if ((_i_ == _s_->fd_count)) {_s_->fd_array[_s_->fd_count++] = (fd);}  \
-        } while(0)
+  do {                                                                     \
+    u_int _i_ = 0;                                                        \
+    fd_set*const _s_ = (fd_set*) (pset);                                  \
+    while ((_i_ < _s_->fd_count) && ((fd) != _s_->fd_array [_i_])) {++_i_;} \
+    if ((_i_ == _s_->fd_count)) {_s_->fd_array [_s_->fd_count ++] = (fd);}  \
+  } while (0)
 #endif
 
- /* MHD_SYS_select_ is wrapper macro for system select() function */
-#if !defined(MHD_WINSOCK_SOCKETS)
-#  define MHD_SYS_select_(n,r,w,e,t) select((n),(r),(w),(e),(t))
+/* MHD_SYS_select_ is wrapper macro for system select() function */
+#if ! defined(MHD_WINSOCK_SOCKETS)
+#  define MHD_SYS_select_(n,r,w,e,t) select ((n),(r),(w),(e),(t))
 #else
 #  define MHD_SYS_select_(n,r,w,e,t) \
-( ( (((void*)(r) == (void*)0) || ((fd_set*)(r))->fd_count == 0) &&  \
-    (((void*)(w) == (void*)0) || ((fd_set*)(w))->fd_count == 0) &&  \
-    (((void*)(e) == (void*)0) || ((fd_set*)(e))->fd_count == 0) ) ? \
-  ( ((void*)(t) == (void*)0) ? 0 :                                  \
-    (Sleep(((struct timeval*)(t))->tv_sec * 1000 +                  \
-           ((struct timeval*)(t))->tv_usec / 1000), 0) ) :          \
-  (select((int)0,(r),(w),(e),(t))) )
+  ( ( (((void*) (r) == (void*) 0) || ((fd_set*) (r))->fd_count == 0) &&  \
+      (((void*) (w) == (void*) 0) || ((fd_set*) (w))->fd_count == 0) &&  \
+      (((void*) (e) == (void*) 0) || ((fd_set*) (e))->fd_count == 0) ) ? \
+    ( ((void*) (t) == (void*) 0) ? 0 :                                  \
+      (Sleep (((struct timeval*) (t))->tv_sec * 1000                    \
+              + ((struct timeval*) (t))->tv_usec / 1000), 0) ) :          \
+    (select ((int) 0,(r),(w),(e),(t))) )
 #endif
 
 #if defined(HAVE_POLL)
 /* MHD_sys_poll_ is wrapper macro for system poll() function */
-#  if !defined(MHD_WINSOCK_SOCKETS)
+#  if ! defined(MHD_WINSOCK_SOCKETS)
 #    define MHD_sys_poll_ poll
 #  else  /* MHD_WINSOCK_SOCKETS */
 #    define MHD_sys_poll_ WSAPoll
@@ -382,16 +396,19 @@
 #  elif defined(__linux__)
 #    define MHD_POLL_EVENTS_ERR_DISC POLLPRI
 #  else /* ! __linux__ */
-#    define MHD_POLL_EVENTS_ERR_DISC (MHD_POLLPRI_OR_ZERO | MHD_POLLRDBAND_OR_ZERO)
+#    define MHD_POLL_EVENTS_ERR_DISC (MHD_POLLPRI_OR_ZERO \
+                                      | MHD_POLLRDBAND_OR_ZERO)
 #  endif /* ! __linux__ */
 /* MHD_POLL_REVENTS_ERR_DISC is 'revents' mask for errors and disconnect.
  * Note: Out-of-band data is treated as error. */
 #  define MHD_POLL_REVENTS_ERR_DISC \
-     (MHD_POLLPRI_OR_ZERO | MHD_POLLRDBAND_OR_ZERO | MHD_POLLNVAL_OR_ZERO | POLLERR | POLLHUP)
+  (MHD_POLLPRI_OR_ZERO | MHD_POLLRDBAND_OR_ZERO | MHD_POLLNVAL_OR_ZERO \
+   | POLLERR | POLLHUP)
 /* MHD_POLL_REVENTS_ERRROR is 'revents' mask for errors.
  * Note: Out-of-band data is treated as error. */
 #  define MHD_POLL_REVENTS_ERRROR \
-     (MHD_POLLPRI_OR_ZERO | MHD_POLLRDBAND_OR_ZERO | MHD_POLLNVAL_OR_ZERO | POLLERR)
+  (MHD_POLLPRI_OR_ZERO | MHD_POLLRDBAND_OR_ZERO | MHD_POLLNVAL_OR_ZERO \
+   | POLLERR)
 #endif /* HAVE_POLL */
 
 #define MHD_SCKT_MISSING_ERR_CODE_ 31450
@@ -525,30 +542,30 @@
 #if defined(MHD_POSIX_SOCKETS)
 #  define MHD_socket_get_error_() (errno)
 #elif defined(MHD_WINSOCK_SOCKETS)
-#  define MHD_socket_get_error_() WSAGetLastError()
+#  define MHD_socket_get_error_() WSAGetLastError ()
 #endif
 
 #ifdef MHD_WINSOCK_SOCKETS
-  /* POSIX-W32 sockets compatibility functions */
+/* POSIX-W32 sockets compatibility functions */
 
 /**
  * Return pointer to string description of specified WinSock error
  * @param err the WinSock error code.
  * @return pointer to string description of specified WinSock error.
  */
-  const char* MHD_W32_strerror_winsock_(int err);
+const char*MHD_W32_strerror_winsock_ (int err);
 #endif /* MHD_WINSOCK_SOCKETS */
 
 /* MHD_socket_last_strerr_ is description string of specified socket error code */
 #if defined(MHD_POSIX_SOCKETS)
-#  define MHD_socket_strerr_(err) strerror((err))
+#  define MHD_socket_strerr_(err) strerror ((err))
 #elif defined(MHD_WINSOCK_SOCKETS)
-#  define MHD_socket_strerr_(err) MHD_W32_strerror_winsock_((err))
+#  define MHD_socket_strerr_(err) MHD_W32_strerror_winsock_ ((err))
 #endif
 
 /* MHD_socket_last_strerr_ is description string of last errno (non-W32) /
  *                            description string of last socket error (W32) */
-#define MHD_socket_last_strerr_() MHD_socket_strerr_(MHD_socket_get_error_())
+#define MHD_socket_last_strerr_() MHD_socket_strerr_ (MHD_socket_get_error_ ())
 
 /**
  * MHD_socket_fset_error_() set socket system native error code.
@@ -556,7 +573,7 @@
 #if defined(MHD_POSIX_SOCKETS)
 #  define MHD_socket_fset_error_(err) (errno = (err))
 #elif defined(MHD_WINSOCK_SOCKETS)
-#  define MHD_socket_fset_error_(err) (WSASetLastError((err)))
+#  define MHD_socket_fset_error_(err) (WSASetLastError ((err)))
 #endif
 
 /**
@@ -568,7 +585,8 @@
  *         and error was not set.
  */
 #define MHD_socket_try_set_error_(err) ( (MHD_SCKT_MISSING_ERR_CODE_ != (err)) ? \
-                                         (MHD_socket_fset_error_((err)), !0) : 0 )
+                                         (MHD_socket_fset_error_ ((err)), ! 0) : \
+                                         0)
 
 /**
  * MHD_socket_set_error_() set socket system native error code to
@@ -581,7 +599,8 @@
                                          (errno = ENOSYS) : (errno = (err)) )
 #  elif defined(EOPNOTSUPP)
 #    define MHD_socket_set_error_(err) ( (MHD_SCKT_MISSING_ERR_CODE_ == (err)) ? \
-                                         (errno = EOPNOTSUPP) : (errno = (err)) )
+                                         (errno = EOPNOTSUPP) : (errno = \
+                                                                   (err)) )
 #  elif defined (EFAULT)
 #    define MHD_socket_set_error_(err) ( (MHD_SCKT_MISSING_ERR_CODE_ == (err)) ? \
                                          (errno = EFAULT) : (errno = (err)) )
@@ -589,13 +608,14 @@
 #    define MHD_socket_set_error_(err) ( (MHD_SCKT_MISSING_ERR_CODE_ == (err)) ? \
                                          (errno = EINVAL) : (errno = (err)) )
 #  else  /* !EOPNOTSUPP && !EFAULT && !EINVAL */
-#    warning No suitable replacement for missing socket error code is found. Edit this file and add replacement code which is defined on system.
+#    warning \
+  No suitable replacement for missing socket error code is found. Edit this file and add replacement code which is defined on system.
 #    define MHD_socket_set_error_(err) (errno = (err))
 #  endif /* !EOPNOTSUPP && !EFAULT && !EINVAL*/
 #elif defined(MHD_WINSOCK_SOCKETS)
 #  define MHD_socket_set_error_(err) ( (MHD_SCKT_MISSING_ERR_CODE_ == (err)) ? \
-                                       (WSASetLastError((WSAEOPNOTSUPP))) : \
-                                       (WSASetLastError((err))) )
+                                       (WSASetLastError ((WSAEOPNOTSUPP))) : \
+                                       (WSASetLastError ((err))) )
 #endif
 
 /**
@@ -619,7 +639,8 @@
  *         last socket error equals to MHD_SCKT_E*_ @a code;
  *         boolean false otherwise
  */
-#define MHD_SCKT_LAST_ERR_IS_(code) MHD_SCKT_ERR_IS_(MHD_socket_get_error_() ,(code))
+#define MHD_SCKT_LAST_ERR_IS_(code) MHD_SCKT_ERR_IS_ (MHD_socket_get_error_ (), \
+                                                      (code))
 
 /* Specific error code checks */
 
@@ -629,7 +650,7 @@
  * @return boolean true if @a err is equal to sockets' EINTR code;
  *         boolean false otherwise.
  */
-#define MHD_SCKT_ERR_IS_EINTR_(err) MHD_SCKT_ERR_IS_((err),MHD_SCKT_EINTR_)
+#define MHD_SCKT_ERR_IS_EINTR_(err) MHD_SCKT_ERR_IS_ ((err),MHD_SCKT_EINTR_)
 
 /**
  * Check whether given socket error is equal to system's
@@ -638,10 +659,12 @@
  *         boolean false otherwise.
  */
 #if MHD_SCKT_EAGAIN_ == MHD_SCKT_EWOULDBLOCK_
-#  define MHD_SCKT_ERR_IS_EAGAIN_(err) MHD_SCKT_ERR_IS_((err),MHD_SCKT_EAGAIN_)
+#  define MHD_SCKT_ERR_IS_EAGAIN_(err) MHD_SCKT_ERR_IS_ ((err),MHD_SCKT_EAGAIN_)
 #else  /* MHD_SCKT_EAGAIN_ != MHD_SCKT_EWOULDBLOCK_ */
-#  define MHD_SCKT_ERR_IS_EAGAIN_(err) ( MHD_SCKT_ERR_IS_((err),MHD_SCKT_EAGAIN_) || \
-                                         MHD_SCKT_ERR_IS_((err),MHD_SCKT_EWOULDBLOCK_) )
+#  define MHD_SCKT_ERR_IS_EAGAIN_(err) (MHD_SCKT_ERR_IS_ ((err), \
+                                                          MHD_SCKT_EAGAIN_) || \
+                                        MHD_SCKT_ERR_IS_ ((err), \
+                                                          MHD_SCKT_EWOULDBLOCK_) )
 #endif /* MHD_SCKT_EAGAIN_ != MHD_SCKT_EWOULDBLOCK_ */
 
 /**
@@ -649,10 +672,17 @@
  * @return boolean true if @a err is any kind of "low resource" error,
  *         boolean false otherwise.
  */
-#define MHD_SCKT_ERR_IS_LOW_RESOURCES_(err) ( MHD_SCKT_ERR_IS_((err),MHD_SCKT_EMFILE_) || \
-                                              MHD_SCKT_ERR_IS_((err),MHD_SCKT_ENFILE_) || \
-                                              MHD_SCKT_ERR_IS_((err),MHD_SCKT_ENOMEM_) || \
-                                              MHD_SCKT_ERR_IS_((err),MHD_SCKT_ENOBUFS_) )
+#define MHD_SCKT_ERR_IS_LOW_RESOURCES_(err) (MHD_SCKT_ERR_IS_ ((err), \
+                                                               MHD_SCKT_EMFILE_) \
+                                             || \
+                                             MHD_SCKT_ERR_IS_ ((err), \
+                                                               MHD_SCKT_ENFILE_) \
+                                             || \
+                                             MHD_SCKT_ERR_IS_ ((err), \
+                                                               MHD_SCKT_ENOMEM_) \
+                                             || \
+                                             MHD_SCKT_ERR_IS_ ((err), \
+                                                               MHD_SCKT_ENOBUFS_) )
 
 /**
  * Check whether is given socket error is type of "incoming connection
@@ -661,9 +691,11 @@
  *         boolean false otherwise.
  */
 #if defined(MHD_POSIX_SOCKETS)
-#  define MHD_SCKT_ERR_IS_DISCNN_BEFORE_ACCEPT_(err) MHD_SCKT_ERR_IS_((err),MHD_SCKT_ECONNABORTED_)
+#  define MHD_SCKT_ERR_IS_DISCNN_BEFORE_ACCEPT_(err) MHD_SCKT_ERR_IS_ ((err), \
+                                                                       MHD_SCKT_ECONNABORTED_)
 #elif defined(MHD_WINSOCK_SOCKETS)
-#  define MHD_SCKT_ERR_IS_DISCNN_BEFORE_ACCEPT_(err) MHD_SCKT_ERR_IS_((err),MHD_SCKT_ECONNRESET_)
+#  define MHD_SCKT_ERR_IS_DISCNN_BEFORE_ACCEPT_(err) MHD_SCKT_ERR_IS_ ((err), \
+                                                                       MHD_SCKT_ECONNRESET_)
 #endif
 
 /**
@@ -672,8 +704,11 @@
  * @return boolean true is @a err match described socket error code,
  *         boolean false otherwise.
  */
-#define MHD_SCKT_ERR_IS_REMOTE_DISCNN_(err) ( MHD_SCKT_ERR_IS_((err),MHD_SCKT_ECONNRESET_) || \
-                                              MHD_SCKT_ERR_IS_((err),MHD_SCKT_ECONNABORTED_))
+#define MHD_SCKT_ERR_IS_REMOTE_DISCNN_(err) (MHD_SCKT_ERR_IS_ ((err), \
+                                                               MHD_SCKT_ECONNRESET_) \
+                                             || \
+                                             MHD_SCKT_ERR_IS_ ((err), \
+                                                               MHD_SCKT_ECONNABORTED_))
 
 /* Specific error code set */
 
@@ -682,12 +717,16 @@
  * available on platform.
  */
 #if MHD_SCKT_MISSING_ERR_CODE_ != MHD_SCKT_ENOMEM_
-#  define MHD_socket_set_error_to_ENOMEM() MHD_socket_set_error_(MHD_SCKT_ENOMEM_)
+#  define MHD_socket_set_error_to_ENOMEM() MHD_socket_set_error_ ( \
+    MHD_SCKT_ENOMEM_)
 #elif MHD_SCKT_MISSING_ERR_CODE_ != MHD_SCKT_ENOBUFS_
-#  define MHD_socket_set_error_to_ENOMEM() MHD_socket_set_error_(MHD_SCKT_ENOBUFS_)
+#  define MHD_socket_set_error_to_ENOMEM() MHD_socket_set_error_ ( \
+    MHD_SCKT_ENOBUFS_)
 #else
-#  warning No suitable replacement for ENOMEM error codes is found. Edit this file and add replacement code which is defined on system.
-#  define MHD_socket_set_error_to_ENOMEM() MHD_socket_set_error_(MHD_SCKT_ENOMEM_)
+#  warning \
+  No suitable replacement for ENOMEM error codes is found. Edit this file and add replacement code which is defined on system.
+#  define MHD_socket_set_error_to_ENOMEM() MHD_socket_set_error_ ( \
+    MHD_SCKT_ENOMEM_)
 #endif
 
 /* Socket functions */
@@ -699,22 +738,26 @@
 #endif /* AF_UNIX */
 
 #if defined(MHD_POSIX_SOCKETS) && defined(MHD_SCKT_LOCAL)
-#  define MHD_socket_pair_(fdarr) (!socketpair(MHD_SCKT_LOCAL, SOCK_STREAM, 0, (fdarr)))
+#  define MHD_socket_pair_(fdarr) (! socketpair (MHD_SCKT_LOCAL, SOCK_STREAM, 0, \
+                                                 (fdarr)))
 #  if defined(HAVE_SOCK_NONBLOCK)
-#    define MHD_socket_pair_nblk_(fdarr) (!socketpair(MHD_SCKT_LOCAL, SOCK_STREAM | SOCK_NONBLOCK, 0, (fdarr)))
+#    define MHD_socket_pair_nblk_(fdarr) (! socketpair (MHD_SCKT_LOCAL, \
+                                                        SOCK_STREAM \
+                                                        | SOCK_NONBLOCK, 0, \
+                                                        (fdarr)))
 #  endif /* HAVE_SOCK_NONBLOCK*/
 #elif defined(MHD_WINSOCK_SOCKETS)
-   /**
-    * Create pair of mutually connected TCP/IP sockets on loopback address
-    * @param sockets_pair array to receive resulted sockets
-    * @param non_blk if set to non-zero value, sockets created in non-blocking mode
-    *                otherwise sockets will be in blocking mode
-    * @return non-zero if succeeded, zero otherwise
-    */
-   int MHD_W32_socket_pair_(SOCKET sockets_pair[2], int non_blk);
+/**
+ * Create pair of mutually connected TCP/IP sockets on loopback address
+ * @param sockets_pair array to receive resulted sockets
+ * @param non_blk if set to non-zero value, sockets created in non-blocking mode
+ *                otherwise sockets will be in blocking mode
+ * @return non-zero if succeeded, zero otherwise
+ */
+int MHD_W32_socket_pair_ (SOCKET sockets_pair[2], int non_blk);
 
-#  define MHD_socket_pair_(fdarr) MHD_W32_socket_pair_((fdarr), 0)
-#  define MHD_socket_pair_nblk_(fdarr) MHD_W32_socket_pair_((fdarr), 1)
+#  define MHD_socket_pair_(fdarr) MHD_W32_socket_pair_ ((fdarr), 0)
+#  define MHD_socket_pair_nblk_(fdarr) MHD_W32_socket_pair_ ((fdarr), 1)
 #endif
 
 /**
@@ -744,6 +787,19 @@ int
 MHD_socket_nonblocking_ (MHD_socket sock);
 
 
+/**
+ * Disable Nagle's algorithm on @a sock.  This is what we do by default for
+ * all TCP sockets in MHD, unless the platform does not support the MSG_MORE
+ * or MSG_CORK or MSG_NOPUSH options.
+ *
+ * @param sock socket to manipulate
+ * @param on value to use
+ * @return 0 on success
+ */
+int
+MHD_socket_set_nodelay_ (MHD_socket sock,
+                         bool on);
+
 /**
  * Change socket options to be non-inheritable.
  *
@@ -755,6 +811,30 @@ int
 MHD_socket_noninheritable_ (MHD_socket sock);
 
 
+/**
+ * Enable/disable the cork option.
+ *
+ * TCP_NOPUSH has the same logic as MSG_MSG_MORE.
+ * The two are more or less equivalent by a source
+ * transformation (ie
+ * send(MSG_MORE) => "set TCP_NOPUSH + send() + clear TCP_NOPUSH".
+ * Both of them are really fairly "local", but TCP_NOPUSH has a
+ * _notion_ of persistency that is entirely lacking in MSG_MORE.
+ * ... with TCP_NOPUSH you basically have to know what your last
+ * write is, and clear the bit _before_ that write if you want
+ * to avoid bad latencies.
+ *
+ * See also: https://yarchive.net/comp/linux/sendfile.html
+ *
+ * @param sock socket to manipulate
+ * @param on set to true to enable CORK, false to disable
+ * @return non-zero if succeeded, zero otherwise
+ */
+int
+MHD_socket_cork_ (MHD_socket sock,
+                  bool on);
+
+
 /**
  * Change socket buffering mode to default.
  *
@@ -766,7 +846,7 @@ MHD_socket_buffering_reset_ (MHD_socket sock);
 
 
 #if defined(SOL_SOCKET) && defined(SO_NOSIGPIPE)
-   static const int _MHD_socket_int_one = 1;
+static const int _MHD_socket_int_one = 1;
 /**
  * Change socket options to no signal on remote disconnect.
  *
@@ -774,7 +854,8 @@ MHD_socket_buffering_reset_ (MHD_socket sock);
  * @return non-zero if succeeded, zero otherwise
  */
 #  define MHD_socket_nosignal_(sock) \
-    (!setsockopt((sock),SOL_SOCKET,SO_NOSIGPIPE,&_MHD_socket_int_one,sizeof(_MHD_socket_int_one)))
+  (! setsockopt ((sock),SOL_SOCKET,SO_NOSIGPIPE,&_MHD_socket_int_one, \
+                 sizeof(_MHD_socket_int_one)))
 #endif /* SOL_SOCKET && SO_NOSIGPIPE */
 
 /**
