@@ -719,14 +719,19 @@ ahc_empty (void *cls,
            const char *url,
            const char *method,
            const char *version,
-           const char *upload_data, size_t *upload_data_size,
+           const char *upload_data,
+           size_t *upload_data_size,
            void **unused)
 {
   static int ptr;
   struct MHD_Response *response;
   int ret;
-  (void) cls; (void) url; (void) url; (void) version;  /* Unused. Silent compiler warning. */
-  (void) upload_data; (void) upload_data_size;     /* Unused. Silent compiler warning. */
+  (void) cls;
+  (void) url;
+  (void) url;
+  (void) version;  /* Unused. Silent compiler warning. */
+  (void) upload_data;
+  (void) upload_data_size;     /* Unused. Silent compiler warning. */
 
   if (0 != strcasecmp ("GET", method))
     return MHD_NO;              /* unexpected method */
@@ -739,7 +744,9 @@ ahc_empty (void *cls,
   response = MHD_create_response_from_buffer (0,
                                               NULL,
                                               MHD_RESPMEM_PERSISTENT);
-  ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
+  ret = MHD_queue_response (connection,
+                            MHD_HTTP_OK,
+                            response);
   MHD_destroy_response (response);
   if (ret == MHD_NO)
   {
@@ -751,7 +758,10 @@ ahc_empty (void *cls,
 
 
 static int
-curlExcessFound (CURL *c, curl_infotype type, char *data, size_t size,
+curlExcessFound (CURL *c,
+                 curl_infotype type,
+                 char *data,
+                 size_t size,
                  void *cls)
 {
   static const char *excess_found = "Excess found";
