@@ -53,10 +53,10 @@
 
 #include "mhd_has_in_name.h"
 
-#if defined(CPU_COUNT) && (CPU_COUNT+0) < 2
+#if defined(CPU_COUNT) && (CPU_COUNT + 0) < 2
 #undef CPU_COUNT
 #endif
-#if !defined(CPU_COUNT)
+#if ! defined(CPU_COUNT)
 #define CPU_COUNT 2
 #endif
 
@@ -72,13 +72,13 @@ fork_curl (const char *url)
 {
   pid_t ret;
 
-  ret = fork();
+  ret = fork ();
   if (ret != 0)
     return ret;
   execlp ("curl", "curl", "-s", "-N", "-o", "/dev/null", "-GET", url, NULL);
   fprintf (stderr,
-	   "Failed to exec curl: %s\n",
-	   strerror (errno));
+           "Failed to exec curl: %s\n",
+           strerror (errno));
   _exit (-1);
 }
 
@@ -88,7 +88,7 @@ kill_curl (pid_t pid)
 {
   int status;
 
-  //fprintf (stderr, "Killing curl\n");
+  // fprintf (stderr, "Killing curl\n");
   kill (pid, SIGTERM);
   waitpid (pid, &status, 0);
 }
@@ -97,7 +97,7 @@ kill_curl (pid_t pid)
 static ssize_t
 push_callback (void *cls, uint64_t pos, char *buf, size_t max)
 {
-  (void)cls;(void)pos;	/* Unused. Silent compiler warning. */
+  (void) cls; (void) pos;  /* Unused. Silent compiler warning. */
 
   if (max == 0)
     return 0;
@@ -111,7 +111,7 @@ push_free_callback (void *cls)
 {
   int *ok = cls;
 
-  //fprintf (stderr, "Cleanup callback called!\n");
+  // fprintf (stderr, "Cleanup callback called!\n");
   *ok = 0;
 }
 
@@ -129,23 +129,23 @@ ahc_echo (void *cls,
   const char *me = cls;
   struct MHD_Response *response;
   int ret;
-  (void)url;(void)version;                      /* Unused. Silent compiler warning. */
-  (void)upload_data;(void)upload_data_size;     /* Unused. Silent compiler warning. */
+  (void) url; (void) version;                      /* Unused. Silent compiler warning. */
+  (void) upload_data; (void) upload_data_size;     /* Unused. Silent compiler warning. */
 
-  //fprintf (stderr, "In CB: %s!\n", method);
+  // fprintf (stderr, "In CB: %s!\n", method);
   if (0 != strcmp (me, method))
     return MHD_NO;              /* unexpected method */
   if (&ptr != *unused)
-    {
-      *unused = &ptr;
-      return MHD_YES;
-    }
+  {
+    *unused = &ptr;
+    return MHD_YES;
+  }
   *unused = NULL;
   response = MHD_create_response_from_callback (MHD_SIZE_UNKNOWN,
-						32 * 1024,
-						&push_callback,
-						&ok,
-						&push_free_callback);
+                                                32 * 1024,
+                                                &push_callback,
+                                                &ok,
+                                                &push_free_callback);
   ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
   MHD_destroy_response (response);
   if (ret == MHD_NO)
@@ -165,11 +165,11 @@ testInternalGet ()
   if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
     port = 0;
   else
-    {
-      port = 1180;
-      if (oneone)
-        port += 10;
-    }
+  {
+    port = 1180;
+    if (oneone)
+      port += 10;
+  }
 
   ok = 1;
   d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
@@ -177,21 +177,23 @@ testInternalGet ()
   if (d == NULL)
     return 1;
   if (0 == port)
+  {
+    const union MHD_DaemonInfo *dinfo;
+    dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+    if ((NULL == dinfo) ||(0 == dinfo->port) )
     {
-      const union MHD_DaemonInfo *dinfo;
-      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-      if (NULL == dinfo || 0 == dinfo->port)
-        { MHD_stop_daemon (d); return 32; }
-      port = (int)dinfo->port;
+      MHD_stop_daemon (d); return 32;
     }
+    port = (int) dinfo->port;
+  }
   snprintf (url,
             sizeof (url),
             "http://127.0.0.1:%d/",
             port);
   curl = fork_curl (url);
-  (void)sleep (1);
+  (void) sleep (1);
   kill_curl (curl);
-  (void)sleep (1);
+  (void) sleep (1);
   /* fprintf (stderr, "Stopping daemon!\n"); */
   MHD_stop_daemon (d);
   if (ok != 0)
@@ -211,47 +213,50 @@ testMultithreadedGet ()
   if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
     port = 0;
   else
-    {
-      port = 1181;
-      if (oneone)
-        port += 10;
-    }
+  {
+    port = 1181;
+    if (oneone)
+      port += 10;
+  }
 
   ok = 1;
-  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
+  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION
+                        | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
                         port, NULL, NULL, &ahc_echo, "GET",
-			MHD_OPTION_CONNECTION_TIMEOUT, (unsigned int) 2,
-			MHD_OPTION_END);
+                        MHD_OPTION_CONNECTION_TIMEOUT, (unsigned int) 2,
+                        MHD_OPTION_END);
   if (d == NULL)
     return 16;
   if (0 == port)
+  {
+    const union MHD_DaemonInfo *dinfo;
+    dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+    if ((NULL == dinfo) ||(0 == dinfo->port) )
     {
-      const union MHD_DaemonInfo *dinfo;
-      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-      if (NULL == dinfo || 0 == dinfo->port)
-        { MHD_stop_daemon (d); return 32; }
-      port = (int)dinfo->port;
+      MHD_stop_daemon (d); return 32;
     }
+    port = (int) dinfo->port;
+  }
   snprintf (url,
             sizeof (url),
             "http://127.0.0.1:%d/",
             port);
-  //fprintf (stderr, "Forking cURL!\n");
+  // fprintf (stderr, "Forking cURL!\n");
   curl = fork_curl (url);
-  (void)sleep (1);
+  (void) sleep (1);
   kill_curl (curl);
-  (void)sleep (1);
+  (void) sleep (1);
   curl = fork_curl (url);
-  (void)sleep (1);
+  (void) sleep (1);
   if (ok != 0)
-    {
-      kill_curl (curl);
-      MHD_stop_daemon (d);
-      return 64;
-    }
+  {
+    kill_curl (curl);
+    MHD_stop_daemon (d);
+    return 64;
+  }
   kill_curl (curl);
-  (void)sleep (1);
-  //fprintf (stderr, "Stopping daemon!\n");
+  (void) sleep (1);
+  // fprintf (stderr, "Stopping daemon!\n");
   MHD_stop_daemon (d);
   if (ok != 0)
     return 32;
@@ -271,11 +276,11 @@ testMultithreadedPoolGet ()
   if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
     port = 0;
   else
-    {
-      port = 1182;
-      if (oneone)
-        port += 10;
-    }
+  {
+    port = 1182;
+    if (oneone)
+      port += 10;
+  }
 
   ok = 1;
   d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
@@ -284,22 +289,24 @@ testMultithreadedPoolGet ()
   if (d == NULL)
     return 64;
   if (0 == port)
+  {
+    const union MHD_DaemonInfo *dinfo;
+    dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+    if ((NULL == dinfo) ||(0 == dinfo->port) )
     {
-      const union MHD_DaemonInfo *dinfo;
-      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-      if (NULL == dinfo || 0 == dinfo->port)
-        { MHD_stop_daemon (d); return 32; }
-      port = (int)dinfo->port;
+      MHD_stop_daemon (d); return 32;
     }
+    port = (int) dinfo->port;
+  }
   snprintf (url,
             sizeof (url),
             "http://127.0.0.1:%d/",
             port);
   curl = fork_curl (url);
-  (void)sleep (1);
+  (void) sleep (1);
   kill_curl (curl);
-  (void)sleep (1);
-  //fprintf (stderr, "Stopping daemon!\n");
+  (void) sleep (1);
+  // fprintf (stderr, "Stopping daemon!\n");
   MHD_stop_daemon (d);
   if (ok != 0)
     return 128;
@@ -324,11 +331,11 @@ testExternalGet ()
   if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
     port = 0;
   else
-    {
-      port = 1183;
-      if (oneone)
-        port += 10;
-    }
+  {
+    port = 1183;
+    if (oneone)
+      port += 10;
+  }
 
   ok = 1;
   d = MHD_start_daemon (MHD_USE_ERROR_LOG,
@@ -336,13 +343,15 @@ testExternalGet ()
   if (d == NULL)
     return 256;
   if (0 == port)
+  {
+    const union MHD_DaemonInfo *dinfo;
+    dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+    if ((NULL == dinfo) ||(0 == dinfo->port) )
     {
-      const union MHD_DaemonInfo *dinfo;
-      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-      if (NULL == dinfo || 0 == dinfo->port)
-        { MHD_stop_daemon (d); return 32; }
-      port = (int)dinfo->port;
+      MHD_stop_daemon (d); return 32;
     }
+    port = (int) dinfo->port;
+  }
   snprintf (url,
             sizeof (url),
             "http://127.0.0.1:%d/",
@@ -351,47 +360,47 @@ testExternalGet ()
 
   start = time (NULL);
   while ((time (NULL) - start < 2))
+  {
+    max = 0;
+    FD_ZERO (&rs);
+    FD_ZERO (&ws);
+    FD_ZERO (&es);
+    if (MHD_YES != MHD_get_fdset (d, &rs, &ws, &es, &max))
     {
-      max = 0;
-      FD_ZERO (&rs);
-      FD_ZERO (&ws);
-      FD_ZERO (&es);
-      if (MHD_YES != MHD_get_fdset (d, &rs, &ws, &es, &max))
-        {
-          MHD_stop_daemon (d);
-          return 4096;
-        }
-      tv.tv_sec = 0;
-      tv.tv_usec = 1000;
-      if (-1 == select (max + 1, &rs, &ws, &es, &tv))
-        {
-          if (EINTR != errno)
-            abort ();
-        }
-      MHD_run (d);
+      MHD_stop_daemon (d);
+      return 4096;
     }
+    tv.tv_sec = 0;
+    tv.tv_usec = 1000;
+    if (-1 == select (max + 1, &rs, &ws, &es, &tv))
+    {
+      if (EINTR != errno)
+        abort ();
+    }
+    MHD_run (d);
+  }
   kill_curl (curl);
   start = time (NULL);
   while ((time (NULL) - start < 2))
+  {
+    max = 0;
+    FD_ZERO (&rs);
+    FD_ZERO (&ws);
+    FD_ZERO (&es);
+    if (MHD_YES != MHD_get_fdset (d, &rs, &ws, &es, &max))
     {
-      max = 0;
-      FD_ZERO (&rs);
-      FD_ZERO (&ws);
-      FD_ZERO (&es);
-      if (MHD_YES != MHD_get_fdset (d, &rs, &ws, &es, &max))
-        {
-          MHD_stop_daemon (d);
-          return 4096;
-        }
-      tv.tv_sec = 0;
-      tv.tv_usec = 1000;
-      if (-1 == select (max + 1, &rs, &ws, &es, &tv))
-        {
-          if (EINTR != errno)
-            abort ();
-        }
-      MHD_run (d);
+      MHD_stop_daemon (d);
+      return 4096;
     }
+    tv.tv_sec = 0;
+    tv.tv_usec = 1000;
+    if (-1 == select (max + 1, &rs, &ws, &es, &tv))
+    {
+      if (EINTR != errno)
+        abort ();
+    }
+    MHD_run (d);
+  }
   /* fprintf (stderr, "Stopping daemon!\n"); */
   MHD_stop_daemon (d);
   if (ok != 0)
@@ -404,28 +413,28 @@ int
 main (int argc, char *const *argv)
 {
   unsigned int errorCount = 0;
-  (void)argc;   /* Unused. Silent compiler warning. */
+  (void) argc;   /* Unused. Silent compiler warning. */
 
 #ifndef _WIN32
   /* Solaris has no way to disable SIGPIPE on socket disconnect. */
   if (MHD_NO == MHD_is_feature_supported (MHD_FEATURE_AUTOSUPPRESS_SIGPIPE))
-    {
-      struct sigaction act;
+  {
+    struct sigaction act;
 
-      act.sa_handler = SIG_IGN;
-      sigaction(SIGPIPE, &act, NULL);
-    }
+    act.sa_handler = SIG_IGN;
+    sigaction (SIGPIPE, &act, NULL);
+  }
 #endif /* _WIN32 */
 
-  if (NULL == argv || 0 == argv[0])
+  if ((NULL == argv)||(0 == argv[0]))
     return 99;
   oneone = has_in_name (argv[0], "11");
-  if (MHD_YES == MHD_is_feature_supported(MHD_FEATURE_THREADS))
-    {
-      errorCount += testInternalGet ();
-      errorCount += testMultithreadedGet ();
-      errorCount += testMultithreadedPoolGet ();
-    }
+  if (MHD_YES == MHD_is_feature_supported (MHD_FEATURE_THREADS))
+  {
+    errorCount += testInternalGet ();
+    errorCount += testMultithreadedGet ();
+    errorCount += testMultithreadedPoolGet ();
+  }
   errorCount += testExternalGet ();
   if (errorCount != 0)
     fprintf (stderr, "Error (code: %u)\n", errorCount);
