@@ -45,10 +45,10 @@
 
 #include "mhd_has_in_name.h"
 
-#if defined(CPU_COUNT) && (CPU_COUNT+0) < 2
+#if defined(CPU_COUNT) && (CPU_COUNT + 0) < 2
 #undef CPU_COUNT
 #endif
-#if !defined(CPU_COUNT)
+#if ! defined(CPU_COUNT)
 #define CPU_COUNT 2
 #endif
 
@@ -66,12 +66,12 @@ struct CBC
 
 static void
 completed_cb (void *cls,
-	      struct MHD_Connection *connection,
-	      void **con_cls,
-	      enum MHD_RequestTerminationCode toe)
+              struct MHD_Connection *connection,
+              void **con_cls,
+              enum MHD_RequestTerminationCode toe)
 {
   struct MHD_PostProcessor *pp = *con_cls;
-  (void)cls;(void)connection;(void)toe; /* Unused. Silent compiler warning. */
+  (void) cls; (void) connection; (void) toe; /* Unused. Silent compiler warning. */
 
   if (NULL != pp)
     MHD_destroy_post_processor (pp);
@@ -107,8 +107,8 @@ post_iterator (void *cls,
                const char *value, uint64_t off, size_t size)
 {
   int *eok = cls;
-  (void)kind;(void)filename;(void)content_type; /* Unused. Silent compiler warning. */
-  (void)transfer_encoding;(void)off;            /* Unused. Silent compiler warning. */
+  (void) kind; (void) filename; (void) content_type; /* Unused. Silent compiler warning. */
+  (void) transfer_encoding; (void) off;            /* Unused. Silent compiler warning. */
 
   if ((0 == strcasecmp (key, "name")) &&
       (size == strlen ("daniel")) && (0 == strncmp (value, "daniel", size)))
@@ -133,32 +133,32 @@ ahc_echo (void *cls,
   struct MHD_Response *response;
   struct MHD_PostProcessor *pp;
   int ret;
-  (void)cls;(void)version;      /* Unused. Silent compiler warning. */
+  (void) cls; (void) version;      /* Unused. Silent compiler warning. */
 
   if (0 != strcasecmp ("POST", method))
-    {
-      printf ("METHOD: %s\n", method);
-      return MHD_NO;            /* unexpected method */
-    }
+  {
+    printf ("METHOD: %s\n", method);
+    return MHD_NO;              /* unexpected method */
+  }
   pp = *unused;
   if (pp == NULL)
-    {
-      eok = 0;
-      pp = MHD_create_post_processor (connection, 1024, &post_iterator, &eok);
-      *unused = pp;
-    }
+  {
+    eok = 0;
+    pp = MHD_create_post_processor (connection, 1024, &post_iterator, &eok);
+    *unused = pp;
+  }
   MHD_post_process (pp, upload_data, *upload_data_size);
   if ((eok == 3) && (0 == *upload_data_size))
-    {
-      response = MHD_create_response_from_buffer (strlen (url),
-						  (void *) url,
-						  MHD_RESPMEM_MUST_COPY);
-      ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
-      MHD_destroy_response (response);
-      MHD_destroy_post_processor (pp);
-      *unused = NULL;
-      return ret;
-    }
+  {
+    response = MHD_create_response_from_buffer (strlen (url),
+                                                (void *) url,
+                                                MHD_RESPMEM_MUST_COPY);
+    ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
+    MHD_destroy_response (response);
+    MHD_destroy_post_processor (pp);
+    *unused = NULL;
+    return ret;
+  }
   *upload_data_size = 0;
   return MHD_YES;
 }
@@ -177,32 +177,34 @@ testInternalPost ()
   if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
     port = 0;
   else
-    {
-      port = 1370;
-      if (oneone)
-        port += 10;
-    }
+  {
+    port = 1370;
+    if (oneone)
+      port += 10;
+  }
 
   cbc.buf = buf;
   cbc.size = 2048;
   cbc.pos = 0;
   d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
                         port, NULL, NULL, &ahc_echo, NULL,
-			MHD_OPTION_NOTIFY_COMPLETED, &completed_cb, NULL,
-			MHD_OPTION_END);
+                        MHD_OPTION_NOTIFY_COMPLETED, &completed_cb, NULL,
+                        MHD_OPTION_END);
   if (d == NULL)
     return 1;
   if (0 == port)
+  {
+    const union MHD_DaemonInfo *dinfo;
+    dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+    if ((NULL == dinfo) ||(0 == dinfo->port) )
     {
-      const union MHD_DaemonInfo *dinfo;
-      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-      if (NULL == dinfo || 0 == dinfo->port)
-        { MHD_stop_daemon (d); return 32; }
-      port = (int)dinfo->port;
+      MHD_stop_daemon (d); return 32;
     }
+    port = (int) dinfo->port;
+  }
   c = curl_easy_init ();
   curl_easy_setopt (c, CURLOPT_URL, "http://127.0.0.1/hello_world");
-  curl_easy_setopt (c, CURLOPT_PORT, (long)port);
+  curl_easy_setopt (c, CURLOPT_PORT, (long) port);
   curl_easy_setopt (c, CURLOPT_WRITEFUNCTION, &copyBuffer);
   curl_easy_setopt (c, CURLOPT_WRITEDATA, &cbc);
   curl_easy_setopt (c, CURLOPT_POSTFIELDS, POST_DATA);
@@ -220,14 +222,14 @@ testInternalPost ()
    *   crashes on my system! */
   curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
   if (CURLE_OK != (errornum = curl_easy_perform (c)))
-    {
-      fprintf (stderr,
-               "curl_easy_perform failed: `%s'\n",
-               curl_easy_strerror (errornum));
-      curl_easy_cleanup (c);
-      MHD_stop_daemon (d);
-      return 2;
-    }
+  {
+    fprintf (stderr,
+             "curl_easy_perform failed: `%s'\n",
+             curl_easy_strerror (errornum));
+    curl_easy_cleanup (c);
+    MHD_stop_daemon (d);
+    return 2;
+  }
   curl_easy_cleanup (c);
   MHD_stop_daemon (d);
   if (cbc.pos != strlen ("/hello_world"))
@@ -250,32 +252,35 @@ testMultithreadedPost ()
   if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
     port = 0;
   else
-    {
-      port = 1371;
-      if (oneone)
-        port += 10;
-    }
+  {
+    port = 1371;
+    if (oneone)
+      port += 10;
+  }
 
   cbc.buf = buf;
   cbc.size = 2048;
   cbc.pos = 0;
-  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
+  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION
+                        | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
                         port, NULL, NULL, &ahc_echo, NULL,
-			MHD_OPTION_NOTIFY_COMPLETED, &completed_cb, NULL,
-			MHD_OPTION_END);
+                        MHD_OPTION_NOTIFY_COMPLETED, &completed_cb, NULL,
+                        MHD_OPTION_END);
   if (d == NULL)
     return 16;
   if (0 == port)
+  {
+    const union MHD_DaemonInfo *dinfo;
+    dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+    if ((NULL == dinfo) ||(0 == dinfo->port) )
     {
-      const union MHD_DaemonInfo *dinfo;
-      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-      if (NULL == dinfo || 0 == dinfo->port)
-        { MHD_stop_daemon (d); return 32; }
-      port = (int)dinfo->port;
+      MHD_stop_daemon (d); return 32;
     }
+    port = (int) dinfo->port;
+  }
   c = curl_easy_init ();
   curl_easy_setopt (c, CURLOPT_URL, "http://127.0.0.1/hello_world");
-  curl_easy_setopt (c, CURLOPT_PORT, (long)port);
+  curl_easy_setopt (c, CURLOPT_PORT, (long) port);
   curl_easy_setopt (c, CURLOPT_WRITEFUNCTION, &copyBuffer);
   curl_easy_setopt (c, CURLOPT_WRITEDATA, &cbc);
   curl_easy_setopt (c, CURLOPT_POSTFIELDS, POST_DATA);
@@ -293,14 +298,14 @@ testMultithreadedPost ()
    *   crashes on my system! */
   curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
   if (CURLE_OK != (errornum = curl_easy_perform (c)))
-    {
-      fprintf (stderr,
-               "curl_easy_perform failed: `%s'\n",
-               curl_easy_strerror (errornum));
-      curl_easy_cleanup (c);
-      MHD_stop_daemon (d);
-      return 32;
-    }
+  {
+    fprintf (stderr,
+             "curl_easy_perform failed: `%s'\n",
+             curl_easy_strerror (errornum));
+    curl_easy_cleanup (c);
+    MHD_stop_daemon (d);
+    return 32;
+  }
   curl_easy_cleanup (c);
   MHD_stop_daemon (d);
   if (cbc.pos != strlen ("/hello_world"))
@@ -323,11 +328,11 @@ testMultithreadedPoolPost ()
   if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
     port = 0;
   else
-    {
-      port = 1372;
-      if (oneone)
-        port += 10;
-    }
+  {
+    port = 1372;
+    if (oneone)
+      port += 10;
+  }
 
   cbc.buf = buf;
   cbc.size = 2048;
@@ -335,21 +340,23 @@ testMultithreadedPoolPost ()
   d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
                         port, NULL, NULL, &ahc_echo, NULL,
                         MHD_OPTION_THREAD_POOL_SIZE, CPU_COUNT,
-			MHD_OPTION_NOTIFY_COMPLETED, &completed_cb, NULL,
-			MHD_OPTION_END);
+                        MHD_OPTION_NOTIFY_COMPLETED, &completed_cb, NULL,
+                        MHD_OPTION_END);
   if (d == NULL)
     return 16;
   if (0 == port)
+  {
+    const union MHD_DaemonInfo *dinfo;
+    dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+    if ((NULL == dinfo) ||(0 == dinfo->port) )
     {
-      const union MHD_DaemonInfo *dinfo;
-      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-      if (NULL == dinfo || 0 == dinfo->port)
-        { MHD_stop_daemon (d); return 32; }
-      port = (int)dinfo->port;
+      MHD_stop_daemon (d); return 32;
     }
+    port = (int) dinfo->port;
+  }
   c = curl_easy_init ();
   curl_easy_setopt (c, CURLOPT_URL, "http://127.0.0.1/hello_world");
-  curl_easy_setopt (c, CURLOPT_PORT, (long)port);
+  curl_easy_setopt (c, CURLOPT_PORT, (long) port);
   curl_easy_setopt (c, CURLOPT_WRITEFUNCTION, &copyBuffer);
   curl_easy_setopt (c, CURLOPT_WRITEDATA, &cbc);
   curl_easy_setopt (c, CURLOPT_POSTFIELDS, POST_DATA);
@@ -367,14 +374,14 @@ testMultithreadedPoolPost ()
    *   crashes on my system! */
   curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
   if (CURLE_OK != (errornum = curl_easy_perform (c)))
-    {
-      fprintf (stderr,
-               "curl_easy_perform failed: `%s'\n",
-               curl_easy_strerror (errornum));
-      curl_easy_cleanup (c);
-      MHD_stop_daemon (d);
-      return 32;
-    }
+  {
+    fprintf (stderr,
+             "curl_easy_perform failed: `%s'\n",
+             curl_easy_strerror (errornum));
+    curl_easy_cleanup (c);
+    MHD_stop_daemon (d);
+    return 32;
+  }
   curl_easy_cleanup (c);
   MHD_stop_daemon (d);
   if (cbc.pos != strlen ("/hello_world"))
@@ -411,11 +418,11 @@ testExternalPost ()
   if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
     port = 0;
   else
-    {
-      port = 1373;
-      if (oneone)
-        port += 10;
-    }
+  {
+    port = 1373;
+    if (oneone)
+      port += 10;
+  }
 
   multi = NULL;
   cbc.buf = buf;
@@ -423,21 +430,23 @@ testExternalPost ()
   cbc.pos = 0;
   d = MHD_start_daemon (MHD_USE_ERROR_LOG,
                         port, NULL, NULL, &ahc_echo, NULL,
-			MHD_OPTION_NOTIFY_COMPLETED, &completed_cb, NULL,
-			MHD_OPTION_END);
+                        MHD_OPTION_NOTIFY_COMPLETED, &completed_cb, NULL,
+                        MHD_OPTION_END);
   if (d == NULL)
     return 256;
   if (0 == port)
+  {
+    const union MHD_DaemonInfo *dinfo;
+    dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+    if ((NULL == dinfo) ||(0 == dinfo->port) )
     {
-      const union MHD_DaemonInfo *dinfo;
-      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-      if (NULL == dinfo || 0 == dinfo->port)
-        { MHD_stop_daemon (d); return 32; }
-      port = (int)dinfo->port;
+      MHD_stop_daemon (d); return 32;
     }
+    port = (int) dinfo->port;
+  }
   c = curl_easy_init ();
   curl_easy_setopt (c, CURLOPT_URL, "http://127.0.0.1/hello_world");
-  curl_easy_setopt (c, CURLOPT_PORT, (long)port);
+  curl_easy_setopt (c, CURLOPT_PORT, (long) port);
   curl_easy_setopt (c, CURLOPT_WRITEFUNCTION, &copyBuffer);
   curl_easy_setopt (c, CURLOPT_WRITEDATA, &cbc);
   curl_easy_setopt (c, CURLOPT_POSTFIELDS, POST_DATA);
@@ -458,85 +467,88 @@ testExternalPost ()
 
   multi = curl_multi_init ();
   if (multi == NULL)
-    {
-      curl_easy_cleanup (c);
-      MHD_stop_daemon (d);
-      return 512;
-    }
+  {
+    curl_easy_cleanup (c);
+    MHD_stop_daemon (d);
+    return 512;
+  }
   mret = curl_multi_add_handle (multi, c);
   if (mret != CURLM_OK)
+  {
+    curl_multi_cleanup (multi);
+    curl_easy_cleanup (c);
+    MHD_stop_daemon (d);
+    return 1024;
+  }
+  start = time (NULL);
+  while ((time (NULL) - start < 5) && (multi != NULL))
+  {
+    maxsock = MHD_INVALID_SOCKET;
+    maxposixs = -1;
+    FD_ZERO (&rs);
+    FD_ZERO (&ws);
+    FD_ZERO (&es);
+    curl_multi_perform (multi, &running);
+    mret = curl_multi_fdset (multi, &rs, &ws, &es, &maxposixs);
+    if (mret != CURLM_OK)
     {
+      curl_multi_remove_handle (multi, c);
       curl_multi_cleanup (multi);
       curl_easy_cleanup (c);
       MHD_stop_daemon (d);
-      return 1024;
+      return 2048;
     }
-  start = time (NULL);
-  while ((time (NULL) - start < 5) && (multi != NULL))
-    {
-      maxsock = MHD_INVALID_SOCKET;
-      maxposixs = -1;
-      FD_ZERO (&rs);
-      FD_ZERO (&ws);
-      FD_ZERO (&es);
-      curl_multi_perform (multi, &running);
-      mret = curl_multi_fdset (multi, &rs, &ws, &es, &maxposixs);
-      if (mret != CURLM_OK)
-        {
-          curl_multi_remove_handle (multi, c);
-          curl_multi_cleanup (multi);
-          curl_easy_cleanup (c);
-          MHD_stop_daemon (d);
-          return 2048;
-        }
-      if (MHD_YES != MHD_get_fdset (d, &rs, &ws, &es, &maxsock))
-        {
-          curl_multi_remove_handle (multi, c);
-          curl_multi_cleanup (multi);
-          curl_easy_cleanup (c);
-          MHD_stop_daemon (d);
-          return 4096;
-        }
-      tv.tv_sec = 0;
-      tv.tv_usec = 1000;
-      if (-1 == select (maxposixs + 1, &rs, &ws, &es, &tv))
-        {
-#ifdef MHD_POSIX_SOCKETS
-          if (EINTR != errno)
-            abort ();
-#else
-          if (WSAEINVAL != WSAGetLastError() || 0 != rs.fd_count || 0 != ws.fd_count || 0 != es.fd_count)
-            abort ();
-          Sleep (1000);
-#endif
-        }
-      curl_multi_perform (multi, &running);
-      if (running == 0)
-        {
-          msg = curl_multi_info_read (multi, &running);
-          if (msg == NULL)
-            break;
-          if (msg->msg == CURLMSG_DONE)
-            {
-              if (msg->data.result != CURLE_OK)
-                printf ("%s failed at %s:%d: `%s'\n",
-                        "curl_multi_perform",
-                        __FILE__,
-                        __LINE__, curl_easy_strerror (msg->data.result));
-              curl_multi_remove_handle (multi, c);
-              curl_multi_cleanup (multi);
-              curl_easy_cleanup (c);
-              c = NULL;
-              multi = NULL;
-            }
-        }      MHD_run (d);
-    }
-  if (multi != NULL)
+    if (MHD_YES != MHD_get_fdset (d, &rs, &ws, &es, &maxsock))
     {
       curl_multi_remove_handle (multi, c);
-      curl_easy_cleanup (c);
       curl_multi_cleanup (multi);
+      curl_easy_cleanup (c);
+      MHD_stop_daemon (d);
+      return 4096;
     }
+    tv.tv_sec = 0;
+    tv.tv_usec = 1000;
+    if (-1 == select (maxposixs + 1, &rs, &ws, &es, &tv))
+    {
+#ifdef MHD_POSIX_SOCKETS
+      if (EINTR != errno)
+        abort ();
+#else
+      if ((WSAEINVAL != WSAGetLastError ()) ||(0 != rs.fd_count) ||(0 !=
+                                                                    ws.fd_count)
+          ||(0 != es.fd_count) )
+        abort ();
+      Sleep (1000);
+#endif
+    }
+    curl_multi_perform (multi, &running);
+    if (running == 0)
+    {
+      msg = curl_multi_info_read (multi, &running);
+      if (msg == NULL)
+        break;
+      if (msg->msg == CURLMSG_DONE)
+      {
+        if (msg->data.result != CURLE_OK)
+          printf ("%s failed at %s:%d: `%s'\n",
+                  "curl_multi_perform",
+                  __FILE__,
+                  __LINE__, curl_easy_strerror (msg->data.result));
+        curl_multi_remove_handle (multi, c);
+        curl_multi_cleanup (multi);
+        curl_easy_cleanup (c);
+        c = NULL;
+        multi = NULL;
+      }
+    }
+    MHD_run (d);
+  }
+  if (multi != NULL)
+  {
+    curl_multi_remove_handle (multi, c);
+    curl_easy_cleanup (c);
+    curl_multi_cleanup (multi);
+  }
   MHD_stop_daemon (d);
   if (cbc.pos != strlen ("/hello_world"))
     return 8192;
@@ -548,43 +560,43 @@ testExternalPost ()
 
 static int
 ahc_cancel (void *cls,
-	    struct MHD_Connection *connection,
-	    const char *url,
-	    const char *method,
-	    const char *version,
-	    const char *upload_data, size_t *upload_data_size,
-	    void **unused)
+            struct MHD_Connection *connection,
+            const char *url,
+            const char *method,
+            const char *version,
+            const char *upload_data, size_t *upload_data_size,
+            void **unused)
 {
   struct MHD_Response *response;
   int ret;
-  (void)cls;(void)url;(void)version;            /* Unused. Silent compiler warning. */
-  (void)upload_data;(void)upload_data_size;     /* Unused. Silent compiler warning. */
+  (void) cls; (void) url; (void) version;            /* Unused. Silent compiler warning. */
+  (void) upload_data; (void) upload_data_size;     /* Unused. Silent compiler warning. */
 
   if (0 != strcasecmp ("POST", method))
-    {
-      fprintf (stderr,
-	       "Unexpected method `%s'\n", method);
-      return MHD_NO;
-    }
+  {
+    fprintf (stderr,
+             "Unexpected method `%s'\n", method);
+    return MHD_NO;
+  }
 
   if (*unused == NULL)
-    {
-      *unused = "wibble";
-      /* We don't want the body. Send a 500. */
-      response = MHD_create_response_from_buffer (0, NULL,
-						  MHD_RESPMEM_PERSISTENT);
-      ret = MHD_queue_response(connection, 500, response);
-      if (ret != MHD_YES)
-	fprintf(stderr, "Failed to queue response\n");
-      MHD_destroy_response(response);
-      return ret;
-    }
+  {
+    *unused = "wibble";
+    /* We don't want the body. Send a 500. */
+    response = MHD_create_response_from_buffer (0, NULL,
+                                                MHD_RESPMEM_PERSISTENT);
+    ret = MHD_queue_response (connection, 500, response);
+    if (ret != MHD_YES)
+      fprintf (stderr, "Failed to queue response\n");
+    MHD_destroy_response (response);
+    return ret;
+  }
   else
-    {
-      fprintf(stderr,
-	      "In ahc_cancel again. This should not happen.\n");
-      return MHD_NO;
-    }
+  {
+    fprintf (stderr,
+             "In ahc_cancel again. This should not happen.\n");
+    return MHD_NO;
+  }
 }
 
 struct CRBC
@@ -596,7 +608,7 @@ struct CRBC
 
 
 static size_t
-readBuffer(void *p, size_t size, size_t nmemb, void *opaque)
+readBuffer (void *p, size_t size, size_t nmemb, void *opaque)
 {
   struct CRBC *data = opaque;
   size_t required = size * nmemb;
@@ -605,18 +617,18 @@ readBuffer(void *p, size_t size, size_t nmemb, void *opaque)
   if (required > left)
     required = left;
 
-  memcpy(p, data->buffer + data->pos, required);
+  memcpy (p, data->buffer + data->pos, required);
   data->pos += required;
 
-  return required/size;
+  return required / size;
 }
 
 
 static size_t
-slowReadBuffer(void *p, size_t size, size_t nmemb, void *opaque)
+slowReadBuffer (void *p, size_t size, size_t nmemb, void *opaque)
 {
-  (void)sleep(1);
-  return readBuffer(p, size, nmemb, opaque);
+  (void) sleep (1);
+  return readBuffer (p, size, nmemb, opaque);
 }
 
 
@@ -628,7 +640,7 @@ slowReadBuffer(void *p, size_t size, size_t nmemb, void *opaque)
 
 
 static int
-testMultithreadedPostCancelPart(int flags)
+testMultithreadedPostCancelPart (int flags)
 {
   struct MHD_Daemon *d;
   CURL *c;
@@ -645,44 +657,48 @@ testMultithreadedPostCancelPart(int flags)
   if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
     port = 0;
   else
-    {
-      port = 1374;
-      if (oneone)
-        port += 10;
-    }
+  {
+    port = 1374;
+    if (oneone)
+      port += 10;
+  }
 
   /* Don't test features that aren't available with HTTP/1.0 in
    * HTTP/1.0 mode. */
-  if (!oneone && (flags & (FLAG_EXPECT_CONTINUE | FLAG_CHUNKED)))
+  if (! oneone && (flags & (FLAG_EXPECT_CONTINUE | FLAG_CHUNKED)))
     return 0;
 
   cbc.buf = buf;
   cbc.size = 2048;
   cbc.pos = 0;
-  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
+  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION
+                        | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
                         port, NULL, NULL, &ahc_cancel, NULL,
-			MHD_OPTION_END);
+                        MHD_OPTION_END);
   if (d == NULL)
     return 32768;
   if (0 == port)
+  {
+    const union MHD_DaemonInfo *dinfo;
+    dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+    if ((NULL == dinfo) ||(0 == dinfo->port) )
     {
-      const union MHD_DaemonInfo *dinfo;
-      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
-      if (NULL == dinfo || 0 == dinfo->port)
-        { MHD_stop_daemon (d); return 32; }
-      port = (int)dinfo->port;
+      MHD_stop_daemon (d); return 32;
     }
+    port = (int) dinfo->port;
+  }
 
   crbc.buffer = "Test content";
-  crbc.size = strlen(crbc.buffer);
+  crbc.size = strlen (crbc.buffer);
   crbc.pos = 0;
 
   c = curl_easy_init ();
   curl_easy_setopt (c, CURLOPT_URL, "http://127.0.0.1/hello_world");
-  curl_easy_setopt (c, CURLOPT_PORT, (long)port);
+  curl_easy_setopt (c, CURLOPT_PORT, (long) port);
   curl_easy_setopt (c, CURLOPT_WRITEFUNCTION, &copyBuffer);
   curl_easy_setopt (c, CURLOPT_WRITEDATA, &cbc);
-  curl_easy_setopt (c, CURLOPT_READFUNCTION, (flags & FLAG_SLOW_READ) ? &slowReadBuffer : &readBuffer);
+  curl_easy_setopt (c, CURLOPT_READFUNCTION, (flags & FLAG_SLOW_READ) ?
+                    &slowReadBuffer : &readBuffer);
   curl_easy_setopt (c, CURLOPT_READDATA, &crbc);
   curl_easy_setopt (c, CURLOPT_POSTFIELDS, NULL);
   curl_easy_setopt (c, CURLOPT_POSTFIELDSIZE, crbc.size);
@@ -700,68 +716,72 @@ testMultithreadedPostCancelPart(int flags)
   curl_easy_setopt (c, CURLOPT_NOSIGNAL, 1L);
 
   if (flags & FLAG_CHUNKED)
-      headers = curl_slist_append(headers, "Transfer-Encoding: chunked");
-  if (!(flags & FLAG_FORM_DATA))
-  headers = curl_slist_append(headers, "Content-Type: application/octet-stream");
+    headers = curl_slist_append (headers, "Transfer-Encoding: chunked");
+  if (! (flags & FLAG_FORM_DATA))
+    headers = curl_slist_append (headers,
+                                 "Content-Type: application/octet-stream");
   if (flags & FLAG_EXPECT_CONTINUE)
-      headers = curl_slist_append(headers, "Expect: 100-Continue");
-  curl_easy_setopt(c, CURLOPT_HTTPHEADER, headers);
+    headers = curl_slist_append (headers, "Expect: 100-Continue");
+  curl_easy_setopt (c, CURLOPT_HTTPHEADER, headers);
 
   if (CURLE_HTTP_RETURNED_ERROR != (errornum = curl_easy_perform (c)))
-    {
+  {
 #ifdef _WIN32
-      curl_version_info_data *curlverd = curl_version_info(CURLVERSION_NOW);
-      if (0 != (flags & FLAG_SLOW_READ) && CURLE_RECV_ERROR == errornum &&
-          (curlverd == NULL || curlverd->ares_num < 0x073100) )
-        { /* libcurl up to version 7.49.0 didn't have workaround for WinSock bug */
-          fprintf (stderr, "Ignored curl_easy_perform expected failure on W32 with \"slow read\".\n");
-          result = 0;
-        }
-      else
-#else  /* ! _WIN32 */
-      if(1)
-#endif /* ! _WIN32 */
-        {
-          fprintf (stderr,
-                   "flibbet curl_easy_perform didn't fail as expected: `%s' %d\n",
-                   curl_easy_strerror (errornum), errornum);
-          result = 65536;
-        }
-      curl_easy_cleanup (c);
-      MHD_stop_daemon (d);
-      curl_slist_free_all(headers);
-      return result;
+    curl_version_info_data *curlverd = curl_version_info (CURLVERSION_NOW);
+    if ((0 != (flags & FLAG_SLOW_READ)) &&(CURLE_RECV_ERROR == errornum) &&
+        ((curlverd == NULL) ||(curlverd->ares_num < 0x073100) ) )
+    {     /* libcurl up to version 7.49.0 didn't have workaround for WinSock bug */
+      fprintf (stderr,
+               "Ignored curl_easy_perform expected failure on W32 with \"slow read\".\n");
+      result = 0;
     }
-
-  if (CURLE_OK != (cc = curl_easy_getinfo(c, CURLINFO_RESPONSE_CODE, &response_code)))
+    else
+#else  /* ! _WIN32 */
+    if (1)
+#endif /* ! _WIN32 */
     {
-      fprintf(stderr, "curl_easy_getinfo failed: '%s'\n", curl_easy_strerror(errornum));
+      fprintf (stderr,
+               "flibbet curl_easy_perform didn't fail as expected: `%s' %d\n",
+               curl_easy_strerror (errornum), errornum);
       result = 65536;
     }
+    curl_easy_cleanup (c);
+    MHD_stop_daemon (d);
+    curl_slist_free_all (headers);
+    return result;
+  }
 
-  if (!result && (response_code != 500))
-    {
-      fprintf(stderr, "Unexpected response code: %ld\n", response_code);
-      result = 131072;
-    }
+  if (CURLE_OK != (cc = curl_easy_getinfo (c, CURLINFO_RESPONSE_CODE,
+                                           &response_code)))
+  {
+    fprintf (stderr, "curl_easy_getinfo failed: '%s'\n", curl_easy_strerror (
+               errornum));
+    result = 65536;
+  }
 
-  if (!result && (cbc.pos != 0))
+  if (! result && (response_code != 500))
+  {
+    fprintf (stderr, "Unexpected response code: %ld\n", response_code);
+    result = 131072;
+  }
+
+  if (! result && (cbc.pos != 0))
     result = 262144;
 
   curl_easy_cleanup (c);
   MHD_stop_daemon (d);
-  curl_slist_free_all(headers);
+  curl_slist_free_all (headers);
   return result;
 }
 
 
 static int
-testMultithreadedPostCancel()
+testMultithreadedPostCancel ()
 {
   int result = 0;
   int flags;
-  for(flags = 0; flags < FLAG_COUNT; ++flags)
-    result |= testMultithreadedPostCancelPart(flags);
+  for (flags = 0; flags < FLAG_COUNT; ++flags)
+    result |= testMultithreadedPostCancelPart (flags);
   return result;
 }
 
@@ -770,20 +790,20 @@ int
 main (int argc, char *const *argv)
 {
   unsigned int errorCount = 0;
-  (void)argc;   /* Unused. Silent compiler warning. */
+  (void) argc;   /* Unused. Silent compiler warning. */
 
-  if (NULL == argv || 0 == argv[0])
+  if ((NULL == argv)||(0 == argv[0]))
     return 99;
   oneone = has_in_name (argv[0], "11");
   if (0 != curl_global_init (CURL_GLOBAL_WIN32))
     return 2;
-  if (MHD_YES == MHD_is_feature_supported(MHD_FEATURE_THREADS))
-    {
-      errorCount += testMultithreadedPostCancel ();
-      errorCount += testInternalPost ();
-      errorCount += testMultithreadedPost ();
-      errorCount += testMultithreadedPoolPost ();
-    }
+  if (MHD_YES == MHD_is_feature_supported (MHD_FEATURE_THREADS))
+  {
+    errorCount += testMultithreadedPostCancel ();
+    errorCount += testInternalPost ();
+    errorCount += testMultithreadedPost ();
+    errorCount += testMultithreadedPoolPost ();
+  }
   errorCount += testExternalPost ();
   if (errorCount != 0)
     fprintf (stderr, "Error (code: %u)\n", errorCount);
